#[non_exhaustive]pub struct RuleSetView {
pub index: usize,
pub source_path: String,
pub url_path_prefix: Option<String>,
pub respond_dir_prefix: Option<String>,
pub rules: Vec<RuleView>,
}Expand description
GUI-facing view of one rule set.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.index: usizeIndex within the parent RouteCatalogSnapshot::rule_sets list.
Identifies the rule set across edit commands.
source_path: StringSource file this rule set was loaded from (relative to the project).
url_path_prefix: Option<String>Optional URL path prefix shared across every rule in this set.
respond_dir_prefix: Option<String>Optional respond-dir prefix shared across every rule in this set.
rules: Vec<RuleView>The rules, in evaluation order.